<?php
/**
 * Nanuminet SMS Rest API Sample
 * SMSAPI 문서를 토대로한 샘플 Class 파일이며 해당파일에 대한 별도 설명이나 안내는 제공하지 않습니다.
 * 해당 파일을 참고하셔서 각 시스템 및 개발 환경에 맞게 수정 또는 별도 개발하시기 바랍니다.
 * 2023. 11. 01 
 * Written by Nanuminet dev 
 */
session_start();
class SmsApi 
{
    private $api_url = "https://sms.nanuminet.com/v1/";
    private $api_key = "API KEY";
    private $secret_key	= "SECRET KEY";

    public function __construct()
    {
        //
    }
    
    private function checkAuth()
    {
		
        if(empty($_SESSION['NNM_ACCESS_TOKEN']) OR strtotime($_SESSION['NNM_ACCESS_EXPIRE']) < time()) {
            $date		= date("c"); 
            $hashtype	= "sha256"; 
            $signature	= hash_hmac($hashtype, ($this->api_key . $date), $this->secret_key);

            $send = self::sendApi("auth",null,  false,
                array(
                    'X-NNM-APIKEY: '.$this->api_key,
                    'X-NNM-DATE:'.$date,
                    'X-NNM-SIGNATURE:'.$signature,
                    'X-NNM-HASH:'.$hashtype
                )
            );
            if(empty($send['result'])) {

                return false;
            }

            $_SESSION['NNM_ACCESS_TOKEN'] = $send['access_token'];
            $_SESSION['NNM_ACCESS_EXPIRE'] = $send['expire_date'];
        }
        return true;
    }

    public function sendSms($data = array())
    {        
        $data = empty($data) ? $_POST : $data;
        
		if($data['callback'] && $data['phone'] && $data['msg']) {
			return self::sendApi("send", $data);    
		}
    }

    public function smsCount()
    {       
        return self::sendApi("count");      
    }

    public function sendList($param="")
    {	
         return self::sendApi("list", $param, false);
    }
	
	public function getRow($ym="", $type="", $index=0) {
		//$ym : integer(6) ex: 202311
		//$type :string(1) S|M
		//$index:integer INDEX NUMBER 
		return self::sendApi("get/". $ym . "/" . $type . "/" . $index , "", false);		
	}
	
	public function getCallbackList() {
		return self::sendApi("callback", $param, false);
	}

	private function sendApi($send_type='', $param='', $post=true, $header='')
    {
        
		if($send_type != 'auth' AND !self::checkAuth()) {
			return false;
		}


		if (empty($param)) {
			$post = false;
		}

		if (empty($header) and !empty($_SESSION['NNM_ACCESS_TOKEN'])) {
			$header = array('X-NNM-ACCESSTOKEN: '.$_SESSION['NNM_ACCESS_TOKEN']);
			if ($post === true) {
				$header[] = 'Content-Type: application/x-www-form-urlencoded';
			}
		}	

		$send = self::cUrlSend($this->api_url.$send_type, $param, null, $post, $header);
		$result = json_decode($send, true);
		return json_last_error() === JSON_ERROR_NONE ? $result : array('result'=>false,'msg'=>'json decode error!!','data'=>$send);
			
    }

    private function cUrlSend($sendUrl, $param = '', $timeout = 5, $post = true, $header = '')
    {
        $curl = curl_init();
        if (!empty($header)) {
            curl_setopt($curl, CURLOPT_HTTPHEADER, $header);
        }
        curl_setopt($curl, CURLOPT_POST, $post);
        if (!empty($param)) {
			if (is_array($param)) {
                $param = http_build_query($param);
            }

            if ($post === true) {
                curl_setopt($curl, CURLOPT_POSTFIELDS, $param);
            } else {
				$sendUrl .= "?" . $param;	
			}
        }

        curl_setopt($curl, CURLOPT_URL, $sendUrl);

        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($curl, CURLOPT_TIMEOUT, $timeout);
        curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, $timeout);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
        $data = curl_exec($curl);
        $err = curl_error($curl);
        $errno = curl_errno($curl);
        curl_close($curl);

        if ($errno != 0) {
            return $err;
        }

        return $data;

    }
}